@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 #include <pyside2_qtnetwork_python.h>
@@ -65,60 +59,65 @@
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QWEBSOCKETPROTOCOL_IDX                                   3
-#define SBK_QWEBSOCKETPROTOCOL_VERSION_IDX                           5
-#define SBK_QWEBSOCKETPROTOCOL_CLOSECODE_IDX                         4
-#define SBK_QWEBSOCKETCORSAUTHENTICATOR_IDX                          2
-#define SBK_QWEBSOCKETSERVER_IDX                                     6
-#define SBK_QWEBSOCKETSERVER_SSLMODE_IDX                             7
-#define SBK_QMASKGENERATOR_IDX                                       0
-#define SBK_QWEBSOCKET_IDX                                           1
-#define SBK_QtWebSockets_IDX_COUNT                                   8
-
+enum : int {
+    SBK_QMASKGENERATOR_IDX                                   = 0,
+    SBK_QWEBSOCKET_IDX                                       = 1,
+    SBK_QWEBSOCKETCORSAUTHENTICATOR_IDX                      = 2,
+    SBK_QWEBSOCKETPROTOCOL_IDX                               = 3,
+    SBK_QWEBSOCKETPROTOCOL_VERSION_IDX                       = 5,
+    SBK_QWEBSOCKETPROTOCOL_CLOSECODE_IDX                     = 4,
+    SBK_QWEBSOCKETSERVER_IDX                                 = 6,
+    SBK_QWEBSOCKETSERVER_SSLMODE_IDX                         = 7,
+    SBK_QtWebSockets_IDX_COUNT                               = 8
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtWebSocketsTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtWebSocketsModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtWebSocketsTypeConverters;
 
 // Converter indices
-#define SBK_QTWEBSOCKETS_QLIST_QOBJECTPTR_IDX                        0 // const QList<QObject* > &
-#define SBK_QTWEBSOCKETS_QLIST_QBYTEARRAY_IDX                        1 // QList<QByteArray >
-#define SBK_QTWEBSOCKETS_QLIST_QWEBSOCKETPROTOCOL_VERSION_IDX        2 // QList<QWebSocketProtocol::Version >
-#define SBK_QTWEBSOCKETS_QLIST_QVARIANT_IDX                          3 // QList<QVariant >
-#define SBK_QTWEBSOCKETS_QLIST_QSTRING_IDX                           4 // QList<QString >
-#define SBK_QTWEBSOCKETS_QMAP_QSTRING_QVARIANT_IDX                   5 // QMap<QString,QVariant >
-#define SBK_QtWebSockets_CONVERTERS_IDX_COUNT                        6
-
+enum : int {
+    SBK_QTWEBSOCKETS_QLIST_QOBJECTPTR_IDX                    = 0, // const QList<QObject* > &
+    SBK_QTWEBSOCKETS_QLIST_QBYTEARRAY_IDX                    = 1, // QList<QByteArray >
+    SBK_QTWEBSOCKETS_QLIST_QWEBSOCKETPROTOCOL_VERSION_IDX    = 2, // QList<QWebSocketProtocol::Version >
+    SBK_QTWEBSOCKETS_QLIST_QVARIANT_IDX                      = 3, // QList<QVariant >
+    SBK_QTWEBSOCKETS_QLIST_QSTRING_IDX                       = 4, // QList<QString >
+    SBK_QTWEBSOCKETS_QMAP_QSTRING_QVARIANT_IDX               = 5, // QMap<QString,QVariant >
+    SBK_QtWebSockets_CONVERTERS_IDX_COUNT                    = 6
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QWebSocketProtocol::Version >() { return SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETPROTOCOL_VERSION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QWebSocketProtocol::CloseCode >() { return SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETPROTOCOL_CLOSECODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QWebSocketCorsAuthenticator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETCORSAUTHENTICATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QWebSocketServer::SslMode >() { return SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETSERVER_SSLMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QWebSocketServer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETSERVER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QMaskGenerator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebSocketsTypes[SBK_QMASKGENERATOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QWebSocket >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QWebSocketCorsAuthenticator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETCORSAUTHENTICATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QWebSocketProtocol::Version >() { return SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETPROTOCOL_VERSION_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QWebSocketProtocol::CloseCode >() { return SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETPROTOCOL_CLOSECODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QWebSocketServer::SslMode >() { return SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETSERVER_SSLMODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QWebSocketServer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebSocketsTypes[SBK_QWEBSOCKETSERVER_IDX]); }
 
 } // namespace Shiboken
 
